from PyObjCTools.TestSupport import TestCase
import objc

import MetalFX


class TestMTLFXSpatialScalerHelper(MetalFX.NSObject):
    def colorTextureUsage(self):
        return 1

    def outputTextureUsage(self):
        return 1

    def inputContentWidth(self):
        return 1

    def setInputContentWidth_(self, a):
        pass

    def inputContentHeight(self):
        return 1

    def setInputContentHeight_(self, a):
        pass

    def colorTextureFormat(self):
        return 1

    def outputTextureFormat(self):
        return 1

    def inputWidth(self):
        return 1

    def inputHeight(self):
        return 1

    def outputWidth(self):
        return 1

    def outputHeight(self):
        return 1

    def colorProcessingMode(self):
        return 1


class TestMTLFXSpatialScaler(TestCase):
    def test_constants(self):
        self.assertIsEnumType(MetalFX.MTLFXSpatialScalerColorProcessingMode)
        self.assertEqual(MetalFX.MTLFXSpatialScalerColorProcessingModePerceptual, 0)
        self.assertEqual(MetalFX.MTLFXSpatialScalerColorProcessingModeLinear, 1)
        self.assertEqual(MetalFX.MTLFXSpatialScalerColorProcessingModeHDR, 2)

    def test_protocols(self):
        self.assertProtocolExists("MTLFXSpatialScaler")

    def test_protocol_methods(self):
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.colorTextureUsage, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.outputTextureUsage, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.inputContentWidth, objc._C_NSUInteger
        )
        self.assertArgHasType(
            TestMTLFXSpatialScalerHelper.setInputContentWidth_, 0, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.inputContentHeight, objc._C_NSUInteger
        )
        self.assertArgHasType(
            TestMTLFXSpatialScalerHelper.setInputContentHeight_, 0, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.colorTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.outputTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.inputWidth, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.inputHeight, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.outputWidth, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.outputHeight, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXSpatialScalerHelper.colorProcessingMode, objc._C_NSInteger
        )



"""
Python mapping for the MetalFX framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Metal
import objc
from MetalFX import _metadata
import MetalFX._MetalFX

sys.modules["MetalFX"] = mod = objc.ObjCLazyModule(
    "MetalFX",
    "com.apple.MetalFX",
    objc.pathForFramework("/System/Library/Frameworks/MetalFX.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,  # noqa: F405
        "__loader__": globals().get("__loader__", None),
    },
    (MetalFX._MetalFX, Metal),
)

del sys.modules["MetalFX._metadata"]



from PyObjCTools.TestSupport import TestCase

import MetalFX
import objc


class TestMTLFXTemporalScalerHelper(MetalFX.NSObject):
    def colorTextureUsage(self):
        return 1

    def depthTextureUsage(self):
        return 1

    def motionTextureUsage(self):
        return 1

    def outputTextureUsage(self):
        return 1

    def inputContentWidth(self):
        return 1

    def setInputContentWidth_(self, a):
        pass

    def inputContentHeight(self):
        return 1

    def setInputContentHeight_(self, a):
        pass

    def jitterOffsetX(self):
        return 1

    def jitterOffsetY(self):
        return 1

    def setJitterOffsetX_(self, a):
        pass

    def setJitterOffsetY_(self, a):
        pass

    def motionVectorScaleX(self):
        return 1

    def setMotionVectorScaleX_(self, a):
        pass

    def motionVectorScaleY(self):
        return 1

    def setMotionVectorScaleY_(self, a):
        pass

    def reset(self):
        return 1

    def setReset_(self, a):
        pass

    def colorTextureFormat(self):
        return 1

    def depthTextureFormat(self):
        return 1

    def motionTextureFormat(self):
        return 1

    def outputTextureFormat(self):
        return 1

    def inputWidth(self):
        return 1

    def inputHeight(self):
        return 1

    def outputWidth(self):
        return 1

    def outputHeight(self):
        return 1

    def inputContentMinScale(self):
        return 1

    def inputContentMaxScale(self):
        return 1

    def isDepthReversed(self):
        return 1

    def setDepthReversed_(self, a):
        pass


class TestMTLFXTemporalScaler(TestCase):
    def test_protocols(self):
        self.assertProtocolExists("MTLFXTemporalScaler")

    def test_protocol_methods(self):
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.colorTextureUsage, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.outputTextureUsage, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputContentWidth, objc._C_NSUInteger
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setInputContentWidth_, 0, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputContentHeight, objc._C_NSUInteger
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setInputContentHeight_, 0, objc._C_NSUInteger
        )

        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.jitterOffsetX, objc._C_FLT
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.jitterOffsetY, objc._C_FLT
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setJitterOffsetX_, 0, objc._C_FLT
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setJitterOffsetY_, 0, objc._C_FLT
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.motionVectorScaleX, objc._C_FLT
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setMotionVectorScaleX_,
            0,
            objc._C_FLT,
        )

        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.motionVectorScaleY, objc._C_FLT
        )
        self.assertArgHasType(
            TestMTLFXTemporalScalerHelper.setMotionVectorScaleY_,
            0,
            objc._C_FLT,
        )

        self.assertResultIsBOOL(TestMTLFXTemporalScalerHelper.reset)
        self.assertArgIsBOOL(TestMTLFXTemporalScalerHelper.setReset_, 0)

        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.colorTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.depthTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.motionTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.outputTextureFormat, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputWidth, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputHeight, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.outputWidth, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.outputHeight, objc._C_NSUInteger
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputContentMinScale, objc._C_FLT
        )
        self.assertResultHasType(
            TestMTLFXTemporalScalerHelper.inputContentMaxScale, objc._C_FLT
        )
        self.assertResultIsBOOL(TestMTLFXTemporalScalerHelper.isDepthReversed)
        self.assertArgIsBOOL(TestMTLFXTemporalScalerHelper.setDepthReversed_, 0)

    def test_methods(self):
        self.assertResultIsBOOL(
            MetalFX.MTLFXTemporalScalerDescriptor.isInputContentPropertiesEnabled
        )
        self.assertArgIsBOOL(
            MetalFX.MTLFXTemporalScalerDescriptor.setInputContentPropertiesEnabled_, 0
        )



# This file is generated by objective.metadata
#
# Last update: Thu Oct 20 15:28:11 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$MTLFXSpatialScalerColorProcessingModeHDR@2$MTLFXSpatialScalerColorProcessingModeLinear@1$MTLFXSpatialScalerColorProcessingModePerceptual@0$"""
misc.update(
    {
        "MTLFXSpatialScalerColorProcessingMode": NewType(
            "MTLFXSpatialScalerColorProcessingMode", int
        )
    }
)
misc.update({})
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"MTLFXSpatialScalerDescriptor", b"supportsDevice:", {"retval": {"type": b"Z"}})
    r(
        b"MTLFXTemporalScalerDescriptor",
        b"isAutoExposureEnabled",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"MTLFXTemporalScalerDescriptor",
        b"isInputContentPropertiesEnabled",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"MTLFXTemporalScalerDescriptor",
        b"setAutoExposureEnabled:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"MTLFXTemporalScalerDescriptor",
        b"setInputContentPropertiesEnabled:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"MTLFXTemporalScalerDescriptor", b"supportsDevice:", {"retval": {"type": b"Z"}})
    r(b"NSObject", b"colorProcessingMode", {"required": True, "retval": {"type": b"q"}})
    r(b"NSObject", b"colorTexture", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"colorTextureFormat", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"colorTextureUsage", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"depthTexture", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"depthTextureFormat", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"depthTextureUsage", {"required": True, "retval": {"type": b"Q"}})
    r(
        b"NSObject",
        b"encodeToCommandBuffer:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"exposureTexture", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"fence", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"inputContentHeight", {"required": True, "retval": {"type": b"Q"}})
    r(
        b"NSObject",
        b"inputContentMaxScale",
        {"required": True, "retval": {"type": b"f"}},
    )
    r(
        b"NSObject",
        b"inputContentMinScale",
        {"required": True, "retval": {"type": b"f"}},
    )
    r(b"NSObject", b"inputContentWidth", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"inputHeight", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"inputWidth", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"isDepthReversed", {"required": True, "retval": {"type": b"Z"}})
    r(b"NSObject", b"jitterOffsetX", {"required": True, "retval": {"type": b"f"}})
    r(b"NSObject", b"jitterOffsetY", {"required": True, "retval": {"type": b"f"}})
    r(b"NSObject", b"motionTexture", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"motionTextureFormat", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"motionTextureUsage", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"motionVectorScaleX", {"required": True, "retval": {"type": b"f"}})
    r(b"NSObject", b"motionVectorScaleY", {"required": True, "retval": {"type": b"f"}})
    r(b"NSObject", b"outputHeight", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"outputTexture", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"outputTextureFormat", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"outputTextureUsage", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"outputWidth", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"preExposure", {"required": True, "retval": {"type": b"f"}})
    r(b"NSObject", b"reset", {"required": True, "retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"setColorTexture:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setDepthReversed:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"NSObject",
        b"setDepthTexture:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setExposureTexture:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setFence:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setInputContentHeight:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"Q"}}},
    )
    r(
        b"NSObject",
        b"setInputContentWidth:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"Q"}}},
    )
    r(
        b"NSObject",
        b"setJitterOffsetX:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"f"}}},
    )
    r(
        b"NSObject",
        b"setJitterOffsetY:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"f"}}},
    )
    r(
        b"NSObject",
        b"setMotionTexture:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setMotionVectorScaleX:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"f"}}},
    )
    r(
        b"NSObject",
        b"setMotionVectorScaleY:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"f"}}},
    )
    r(
        b"NSObject",
        b"setOutputTexture:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setPreExposure:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"f"}}},
    )
    r(
        b"NSObject",
        b"setReset:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"Z"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
